@@ -17,7 +17,7 @@ class RedisKey(object):
 
     def __getattr__(self, attr):
         def _(name=''):
-            self(attr, name)
+            return self(attr, name)
         return _
 
     def __call__(self, attr, name=''):
